@@ -1,6 +1,6 @@
 package Bot::BasicBot;
-our $AUTHORITY = 'cpan:HINRIK';
-$Bot::BasicBot::VERSION = '0.90';
+our $AUTHORITY = 'cpan:BIGPRESH';
+$Bot::BasicBot::VERSION = '0.91';
 use strict;
 use warnings;
 
@@ -79,6 +79,9 @@ sub run {
 
                 irc_shutdown     => "shutdown_state",
 
+                irc_raw          => "irc_raw_state",
+                irc_raw_out      => "irc_raw_out_state",
+
                 tick => "tick_state",
             }
         ]
@@ -122,6 +125,9 @@ sub help { return "Sorry, this bot has no interactive help." }
 
 sub connected { return }
 
+sub raw_in  { return }
+sub raw_out { return }
+
 sub userquit {
     my ($self, $mess) = @_;
     return;
@@ -823,6 +829,18 @@ sub shutdown_state {
     return;
 }
 
+
+sub irc_raw_state { 
+    my ($self, $kernel, $raw_line) = @_[OBJECT, KERNEL, ARG0];
+    $self->raw_in($raw_line);
+}
+sub irc_raw_out_state {
+    my ($self, $kernel, $raw_line) = @_[OBJECT, KERNEL, ARG0];
+    $self->raw_out($raw_line);
+}
+
+
+
 sub AUTOLOAD {
     my $self = shift;
     our $AUTOLOAD;
